@@ -60,7 +60,7 @@ struct _GooCanvas
 
   /* Where the canvas is anchored (where it is displayed when it is smaller
      than the entire window). */
-  GtkAnchorType anchor;
+  GooCanvasAnchorType anchor;
 
   /* Idle handler ID, for processing updates. */
   guint idle_id;
@@ -88,8 +88,8 @@ struct _GooCanvas
      useful when there are sticky items to reduce flicker, but is slower. */
   guint redraw_when_scrolled : 1;
 
-  /* If the canvas hasn't received the initial expose event yet. */
-  guint before_initial_expose : 1;
+  /* If the canvas hasn't received the initial draw signal yet. */
+  guint before_initial_draw : 1;
 
   /* This is the padding around the automatic bounds. */
   gdouble bounds_padding;
